AgentRunner

Struct AgentRunner 

pub struct AgentRunner {
    pub tools: Arc<RwLock<Vec<Arc<dyn Tool>>>>,
    pub system_prompt: Arc<RwLock<String>>,
    pub skills: Arc<RwLock<Vec<Skill>>>,
    pub steering_queue: Arc<Mutex<Vec<String>>>,
    pub agent_config: AgentConfig,
    /* private fields */
}

Fields

tools: Arc<RwLock<Vec<Arc<dyn Tool>>>>system_prompt: Arc<RwLock<String>>skills: Arc<RwLock<Vec<Skill>>>steering_queue: Arc<Mutex<Vec<String>>>agent_config: AgentConfig

Implementations

Source

impl AgentRunner

pub fn new( provider: Arc<dyn Provider>, tools: Vec<Arc<dyn Tool>>, memory: Arc<dyn MemoryBackend>, system_prompt: impl Into<String>, model: impl Into<String>, ) -> Self

pub fn set_stream_sink(&self, tx: Option<AgentStreamTx>)

pub fn stream_sink(&self) -> Option<AgentStreamTx>

The sink events go to: the per-turn sink of the current task if one is scoped, otherwise the process-wide sink.

pub fn with_config(self, config: AgentConfig) -> Self

pub fn with_mode(self, mode: AgentMode) -> Self

pub async fn with_plugin_registry(self, registry: PluginRegistry) -> Self

pub fn get_mode(&self) -> AgentMode

pub fn set_mode(&self, mode: AgentMode)

pub fn mode_handle(&self) -> Arc<RwLock<AgentMode>>

pub fn add_hook(&self, hook: Arc<dyn ToolHook>)

pub fn steer(&self, message: String)

pub fn with_workspace(self, workspace: PathBuf) -> Self

pub fn with_memory_ideas(self, cfg: MemoryIdeasConfig) -> Self

pub fn with_memory_enabled(self, enabled: bool) -> Self

Enable or disable conversational memory for this runner.

Restricted automation uses this to keep prior conversations and experiment output out of the model context and persistent stores.

pub fn with_group_chat(self, cfg: GroupChatConfig) -> Self

pub fn with_zkr(self, store: Option<Arc<ZkrStore>>, cfg: ZkrConfig) -> Self

pub async fn with_skills(self, skills: Vec<Skill>) -> Self

pub fn cost_tracker(&self) -> Arc<CostTracker>

pub async fn get_cost_summary(&self) -> CostSummary

pub fn provider_name(&self) -> &str

The name of the provider currently backing model calls.

pub fn memory(&self) -> &Arc<dyn MemoryBackend>

The conversation store, for callers that need to read or clear history.

pub fn get_model(&self) -> String

pub fn get_default_model(&self) -> &str

pub fn set_model(&self, model: impl Into<String>)

pub fn reset_model(&self)

pub async fn list_tools(&self) -> Vec<String>

pub async fn add_tool(&self, tool: Arc<dyn Tool>)

pub fn hook_manager(&self) -> &Arc<HookManager>

Access the hook manager (for plugin tool registration)

pub fn plugin_registry(&self) -> &Arc<RwLock<PluginRegistry>>

Get the plugin registry

pub async fn deploy_coding_swarm( self: Arc<Self>, tasks: Vec<String>, base_chat_id: &str, parallelism: usize, ) -> Vec<(String, String)>

pub async fn run(&self, channel: &mut dyn Channel) -> Result<()>

pub async fn run_with_extra_rx( &self, channel: &mut dyn Channel, extra_rx: Receiver<IncomingMessage>, ) -> Result<()>

pub async fn run_with_runtime_rx( &self, channel: &mut dyn Channel, extra_rx: Receiver<IncomingMessage>, cron_rx: Receiver<DueJob>, scheduler: Arc<CronScheduler>, ) -> Result<()>

pub async fn handle_message( &self, msg: &IncomingMessage, channel: &dyn Channel, ) -> Result<String>

pub async fn handle_message_with_model( &self, msg: &IncomingMessage, channel: &dyn Channel, model: Option<&str>, ) -> Result<String>

pub async fn get_trajectory(&self, chat_id: &str) -> Option<Trajectory>

Get trajectory for a chat (for export)

pub async fn get_all_trajectories(&self) -> Vec<Trajectory>

Get all trajectories

pub async fn save_trajectory(&self, chat_id: &str, dir: &Path) -> Result<()>

Save trajectory to disk