Module stream

Module stream 

Enums

AgentStreamEvent

Functions

current_turn_sink
The sink for the turn running in this task, if any.
emit
with_turn_sink
Run fut with tx as the sink for this turn.

Type Aliases

AgentStreamTx