pub async fn drain_http_server(handle: JoinHandle<()>)Expand description
Wait for the server task to finish draining, up to DRAIN_TIMEOUT.
pub async fn drain_http_server(handle: JoinHandle<()>)Wait for the server task to finish draining, up to DRAIN_TIMEOUT.