run

Function run 

pub async fn run(
    channel: &mut dyn Channel,
    settings: &ChannelSettings,
    opts: &CheckOptions,
) -> Vec<StepReport>
Run the check. Returns the steps, all of which must pass for the channel to be considered verified against the real service.