MCP server mode โ exposes apollo as an MCP server over stdio or HTTP. Other AI clients can connect to prompt apollo or use its tools.
Functions
- run_
mcp_ server - Run apollo as an MCP server over stdio.
- run_
mcp_ server_ http
MCP server mode โ exposes apollo as an MCP server over stdio or HTTP. Other AI clients can connect to prompt apollo or use its tools.