segment_consumes_shell_stdin

Function segment_consumes_shell_stdin 

pub fn segment_consumes_shell_stdin(words: &[String]) -> bool
True when the simple command reads its script from stdin (bash -s, sh -, /dev/stdin, …), including through wrapper binaries such as sudo or env -S.