ToolSearchTool โ keyword search over all available tools.
When many tools are registered, this lets the agent find the right tool by searching names and descriptions without having to remember them all.
ToolSearchTool โ keyword search over all available tools.
When many tools are registered, this lets the agent find the right tool by searching names and descriptions without having to remember them all.